# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
💄 Simpler icons | [83](https://github.com/laminlabs/lamin-utils/pull/83) | [sunnyosun](https://github.com/sunnyosun) | 2024-08-22 |
✨ Improve InspectResult docs and improve typing | [80](https://github.com/laminlabs/lamin-utils/pull/80) | [Zethson](https://github.com/Zethson) | 2024-08-06 |
✨Ruff config | [78](https://github.com/laminlabs/lamin-utils/pull/78) | [Zethson](https://github.com/Zethson) | 2024-08-06 |
✨ Add `logger.mute()` | [77](https://github.com/laminlabs/lamin-utils/pull/77) | [falexwolf](https://github.com/falexwolf) | 2024-04-19 | 0.13.2
🐛 Fix ZeroDivisionError in `inspect` | [75](https://github.com/laminlabs/lamin-utils/pull/75) | [sunnyosun](https://github.com/sunnyosun) | 2024-03-21 | 0.13.1
✨ Add base62 encoding | [73](https://github.com/laminlabs/lamin-utils/pull/73) | [falexwolf](https://github.com/falexwolf) | 2023-12-22 | 0.13.0
✨ Add `return_field` to `standardize` | [72](https://github.com/laminlabs/lamin-utils/pull/72) | [sunnyosun](https://github.com/sunnyosun) | 2023-12-02 | 0.12.0
🚑️ Going back to QRatio | [71](https://github.com/laminlabs/lamin-utils/pull/71) | [sunnyosun](https://github.com/sunnyosun) | 2023-11-04 | 0.11.7
♻️ Default search to token_set_ratio for multi words | [70](https://github.com/laminlabs/lamin-utils/pull/70) | [sunnyosun](https://github.com/sunnyosun) | 2023-11-04 | 0.11.6
🔊 Add a warning for large numbers of lookup items | [69](https://github.com/laminlabs/lamin-utils/pull/69) | [sunnyosun](https://github.com/sunnyosun) | 2023-10-23 |
🐛 Fix logging on Windows | [68](https://github.com/laminlabs/lamin-utils/pull/68) | [Koncopd](https://github.com/Koncopd) | 2023-10-03 | 0.11.4
🔊 Only logs if input is not empty | [67](https://github.com/laminlabs/lamin-utils/pull/67) | [sunnyosun](https://github.com/sunnyosun) | 2023-09-25 |
🎨 Inspect always logs | [66](https://github.com/laminlabs/lamin-utils/pull/66) | [sunnyosun](https://github.com/sunnyosun) | 2023-09-14 |
🔊 Use emoji for Windows | [65](https://github.com/laminlabs/lamin-utils/pull/65) | [sunnyosun](https://github.com/sunnyosun) | 2023-09-14 |
🔥 Remove emoji for print | [64](https://github.com/laminlabs/lamin-utils/pull/64) | [sunnyosun](https://github.com/sunnyosun) | 2023-09-11 |
✨ Added print and important logging level | [63](https://github.com/laminlabs/lamin-utils/pull/63) | [sunnyosun](https://github.com/sunnyosun) | 2023-09-11 | 0.11.0
✨ Added return_field to lookup | [62](https://github.com/laminlabs/lamin-utils/pull/62) | [sunnyosun](https://github.com/sunnyosun) | 2023-09-08 |
🎨 Switch to WRatio and default to limit=20 for search | [61](https://github.com/laminlabs/lamin-utils/pull/61) | [sunnyosun](https://github.com/sunnyosun) | 2023-09-04 | 0.10.6
🚑️ Fix map_synonyms bug | [60](https://github.com/laminlabs/lamin-utils/pull/60) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-31 | 0.10.5
🔊 Improved inspect logging | [59](https://github.com/laminlabs/lamin-utils/pull/59) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-22 |
🔊 Improved logging of inspect | [58](https://github.com/laminlabs/lamin-utils/pull/58) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-22 |
🩹 Also logs if no ref | [57](https://github.com/laminlabs/lamin-utils/pull/57) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-18 |
🔊 Improved validate logging | [56](https://github.com/laminlabs/lamin-utils/pull/56) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-18 | 0.10.2
🔇 No warning is logged if all validated | [55](https://github.com/laminlabs/lamin-utils/pull/55) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-17 |
🎨 Updated save and warning emojis | [54](https://github.com/laminlabs/lamin-utils/pull/54) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-17 | 0.10.0
🔊 Updated logging msg to use standardize | [53](https://github.com/laminlabs/lamin-utils/pull/53) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-16 |
♻️ Refactored validate and inspect | [52](https://github.com/laminlabs/lamin-utils/pull/52) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-08 |
✨ Add InspectResult | [51](https://github.com/laminlabs/lamin-utils/pull/51) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-07 |
🎨 Rename download to save logging level | [50](https://github.com/laminlabs/lamin-utils/pull/50) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-07 | 0.9.5
🎨 Simplified params in inspect | [48](https://github.com/laminlabs/lamin-utils/pull/48) | [sunnyosun](https://github.com/sunnyosun) | 2023-08-06 | 0.9.4
🚸 Introduce success-level verbosity | [49](https://github.com/laminlabs/lamin-utils/pull/49) | [falexwolf](https://github.com/falexwolf) | 2023-08-06 |
Round percentages for mapping | [47](https://github.com/laminlabs/lamin-utils/pull/47) | [Zethson](https://github.com/Zethson) | 2023-07-31 |
🐛 Fix for categorical index | [45](https://github.com/laminlabs/lamin-utils/pull/45) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-25 | 0.9.3
✨ Added italic and underline | [44](https://github.com/laminlabs/lamin-utils/pull/44) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-25 | 0.9.2
🐛 Fix _append_records_to_list in lookup | [43](https://github.com/laminlabs/lamin-utils/pull/43) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-23 |
✨ Allow indenting logging messages | [42](https://github.com/laminlabs/lamin-utils/pull/42) | [falexwolf](https://github.com/falexwolf) | 2023-07-21 | 0.9.0
💚 Fix | [41](https://github.com/laminlabs/lamin-utils/pull/41) | [falexwolf](https://github.com/falexwolf) | 2023-07-21 |
🚚 Rename `lamin_logger` to `lamin_utils` | [40](https://github.com/laminlabs/lamin-utils/pull/40) | [falexwolf](https://github.com/falexwolf) | 2023-07-21 |
🎨 Fix for duplicated values in search | [39](https://github.com/laminlabs/lamin-logger/pull/39) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-19 |
🎨 Return None if searching against Nones | [38](https://github.com/laminlabs/lamin-logger/pull/38) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-18 |
🎨 Always return df for `search`, added `limit=` | [37](https://github.com/laminlabs/lamin-logger/pull/37) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-17 | 0.8.0
🐛 Fix map_synonyms bug | [36](https://github.com/laminlabs/lamin-logger/pull/36) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-14 | 0.7.7
⚡️ Speed up search 150x | [35](https://github.com/laminlabs/lamin-logger/pull/35) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-10 | 0.7.6
🐛 Fix existing_categories for map_synonyms | [34](https://github.com/laminlabs/lamin-logger/pull/34) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-05 | 0.7.5
🚑️ Fix for multiple matches in map_synonyms | [33](https://github.com/laminlabs/lamin-logger/pull/33) | [sunnyosun](https://github.com/sunnyosun) | 2023-07-02 | 0.7.4
🚑️ Handles categorical input | [32](https://github.com/laminlabs/lamin-logger/pull/32) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-30 | 0.7.3
🐛 Fix case sensitivity in map_synonyms | [31](https://github.com/laminlabs/lamin-logger/pull/31) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-22 | 0.7.1
🚚 Moved inspect from bionty | [30](https://github.com/laminlabs/lamin-logger/pull/30) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-21 | 0.7.0
🚑️ Map_synonyms only returns mapped synonyms not names | [29](https://github.com/laminlabs/lamin-logger/pull/29) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-20 | 0.6.2
🧪 Deal with empty dataframes | [28](https://github.com/laminlabs/lamin-logger/pull/28) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-19 | 0.6.1
✨ Add case_sensitive to map_synonyms | [27](https://github.com/laminlabs/lamin-logger/pull/27) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-19 | 0.6.0
🧪 Test every line of search | [25](https://github.com/laminlabs/lamin-logger/pull/25) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-17 | 0.5.3
🚑️ Fix empty string input for `map_synonyms` | [24](https://github.com/laminlabs/lamin-logger/pull/24) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-17 |
💄 Log to stdout rather than stderr | [23](https://github.com/laminlabs/lamin-logger/pull/23) | [falexwolf](https://github.com/falexwolf) | 2023-06-16 | 0.5.2
✨ Lookup can also return sql records | [22](https://github.com/laminlabs/lamin-logger/pull/22) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-15 | 0.5.1
✨ Remove loguru and replace with standard (Scanpy-based) logger | [18](https://github.com/laminlabs/lamin-logger/pull/18) | [falexwolf](https://github.com/falexwolf) | 2023-06-15 | 0.5.0
🚚 Moved search and map_synonyms from bionty here | [21](https://github.com/laminlabs/lamin-logger/pull/21) | [sunnyosun](https://github.com/sunnyosun) | 2023-06-15 | 0.4.0
🚚 Temporarily added lookup | [20](https://github.com/laminlabs/lamin-logger/pull/20) | [falexwolf](https://github.com/falexwolf) | 2023-06-14 | 0.3.4
✨ Added download level, changed info icon to 💬 | [19](https://github.com/laminlabs/lamin-logger/pull/19) | [sunnyosun](https://github.com/sunnyosun) | 2023-05-27 | 0.3.2
:sparkles: Add hint level | [17](https://github.com/laminlabs/lamin-logger/pull/17) | [falexwolf](https://github.com/falexwolf) | 2023-04-05 | 0.3.0
🚸 Add all botocore subloggers | [16](https://github.com/laminlabs/lamin-logger/pull/16) | [falexwolf](https://github.com/falexwolf) | 2023-02-22 | 0.3rc1
🔇 Suppress "Found credentials..." logging in aiobotocore | [15](https://github.com/laminlabs/lamin-logger/pull/15) | [sunnyosun](https://github.com/sunnyosun) | 2023-02-06 | 0.2.4
🚸 Set default level to INFO | [14](https://github.com/laminlabs/lamin-logger/pull/14) | [falexwolf](https://github.com/falexwolf) | 2023-01-24 | 0.2.3
🔥 Manually provide versions for py_version_warning | [13](https://github.com/laminlabs/lamin-logger/pull/13) | [sunnyosun](https://github.com/sunnyosun) | 2023-01-12 | 0.2.2
👷 Added python version warning and extened CI to py3.7-3.11 | [12](https://github.com/laminlabs/lamin-logger/pull/12) | [sunnyosun](https://github.com/sunnyosun) | 2023-01-11 | 0.2.0
⏪ Revert the previous PR | [11](https://github.com/laminlabs/lamin-logger/pull/11) | [sunnyosun](https://github.com/sunnyosun) | 2022-10-20 | 0.1.5
🩹 Suppress numexpr warnings | [10](https://github.com/laminlabs/lamin-logger/pull/10) | [sunnyosun](https://github.com/sunnyosun) | 2022-10-20 | 0.1.4
🚸 Silence boto3 logger | [9](https://github.com/laminlabs/lamin-logger/pull/9) | [falexwolf](https://github.com/falexwolf) | 2022-08-08 | 0.1.3
🚧 Trying to fix emoji display in windows | [7](https://github.com/laminlabs/lamin-logger/pull/7) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-28 | 0.1.2
💄 Remove vertical bar | [6](https://github.com/laminlabs/lamin-logger/pull/6) | [falexwolf](https://github.com/falexwolf) | 2022-07-24 | 0.1.1
🐛 Quick fix for windows | [3](https://github.com/laminlabs/lamin-logger/pull/3) | [Koncopd](https://github.com/Koncopd) | 2022-07-23 |
🔥 Reduce docs to necessary components | [2](https://github.com/laminlabs/lamin-logger/pull/2) | [falexwolf](https://github.com/falexwolf) | 2022-07-20 |
✨ Added logger and colors | [1](https://github.com/laminlabs/lamin-logger/pull/1) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-20 | 0.1.0
